@@ -2,8 +2,9 @@
 
 use Test::Harness qw<runtests>;
 
-my @cores = qw<DumbCache>;   # Slow is already tested by "make test"
-                             # Because it is default
+my @cores = qw<DumbCache DecisionTree>;   
+# Slow is already tested by "make test"
+# Because it is default
 
 for my $core (@cores) {
     $ENV{CMMP_DEFAULT_MULTI_CORE} = $core;
